# coding: utf-8

"""
    DeviceServer

    DeviceServer API  # noqa: E501

    The version of the OpenAPI document: 1.1.9
    Contact: david@3adesign.co.uk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import DeviceServer
from DeviceServer.api.docker_api import DockerApi  # noqa: E501
from DeviceServer.rest import ApiException


class TestDockerApi(unittest.TestCase):
    """DockerApi unit test stubs"""

    def setUp(self):
        self.api = DeviceServer.api.docker_api.DockerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_container_logs(self):
        """Test case for get_container_logs

        GET a docker container's logs  # noqa: E501
        """
        pass

    def test_get_docker_container_names(self):
        """Test case for get_docker_container_names

        GET all docker containers  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DeviceServer

    DeviceServer API  # noqa: E501

    The version of the OpenAPI document: 1.1.9
    Contact: david@3adesign.co.uk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import DeviceServer
from DeviceServer.models.firmware_version import FirmwareVersion  # noqa: E501
from DeviceServer.rest import ApiException

class TestFirmwareVersion(unittest.TestCase):
    """FirmwareVersion unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test FirmwareVersion
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = DeviceServer.models.firmware_version.FirmwareVersion()  # noqa: E501
        if include_optional :
            return FirmwareVersion(
                version = ''
            )
        else :
            return FirmwareVersion(
        )

    def testFirmwareVersion(self):
        """Test FirmwareVersion"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
